//generate_sim_tex_file
//Fonction qui gnre le fichier tex principal
//d'une page de documentation d'un script de 
//simulation scilab

function txt=generate_sim_tex_file(lisf,flag,lang)

 //verify the 'lang' right parameter
 [lsh,rsh]=argn(0)
 if rsh<3 then
   if ~exists('lang') then
    lang='eng'
   elseif lang<>'eng' & lang<>'fr' then
    lang='eng'
   end
 end

 //Generate auxiliary tex files
 lisf=generate_aux_tex_file(lisf,'sim',flag,lang);

 //define title of paragraph
 tt_title=[
           ''                      //tt1  : header du fichier tex
           'Description'           //tt2  : Description (_long)
           'Algorithm'             //tt3  : Algorithm (_algo)
           'Simulation script(s)'  //tt4  : simulation script(s) (_sim_script)
           'Scope Results'         //tt5  : Scope results (_scop)
           'Scicos diagram(s)'     //tt6  : scicos diagram(s) (_diagr)
           'Context file(s)'       //tt7  : file of context(s) (_context)
           'Mod\_num blocks'       //tt8  : Mod num blocks (_block)
           'Used function'         //tt9  : used functions (_used_func)
           'See Also'              //tt10 : See Also (_see_also)
           'Authors'               //tt11 : Authors (_authors)
           'Bibliography'          //tt12 : Bibliography (_bib)
           ''                      //tt13 : End of tex file
          ]

 //change language of title
 if lang=='fr' then
  tt_title=change_lang_title(lang,tt_title);
 end 

 //define level of paragraph
 if flag=='html' then
  tex_title='\subsection{'+tt_title+'}'
 else
  tex_title='\subsection{'+tt_title+'}'
 end

 for i=1:size(lisf,1)
    for j=1:13 execstr('tt'+string(j)+'=[]'),end

    if fileinfo(lisf(i,1)+'/'+lisf(i,1)+'_long.tex')<>[] then //Description
      tt2=[tex_title(2)
           ''
           '\input{'+lisf(i,1)+'_long}']
    end

    if fileinfo(lisf(i,1)+'/'+lisf(i,1)+'_algo.tex')<>[] then //algorithm
      tt3=[tex_title(3)
           '\input{'+lisf(i,1)+'_algo}']
    end

    if fileinfo(lisf(i,1)+'/'+lisf(i,1)+'_sim_script.tex')<>[] then //Simulation scripts
      tt4=[tex_title(4)
           '\input{'+lisf(i,1)+'_sim_script}'] 
    end

    if fileinfo(lisf(i,1)+'/'+lisf(i,1)+'_scop.tex')<>[] then //scop
      tt5=[tex_title(5)
           '\input{'+lisf(i,1)+'_scop}']
    end

    if fileinfo(lisf(i,1)+'/'+lisf(i,1)+'_diagr.tex')<>[] then //Scicos diagram(s)
      tt6=[tex_title(6)
           '\input{'+lisf(i,1)+'_diagr}']
    end

    if fileinfo(lisf(i,1)+'/'+lisf(i,1)+'_context.tex')<>[] then //Context file(s)
      tt7=[tex_title(7)
           '\input{'+lisf(i,1)+'_context}'] 
    end

    if fileinfo(lisf(i,1)+'/'+lisf(i,1)+'_block.tex')<>[] then //mod_num block
      tt8=[tex_title(8)
           '\input{'+lisf(i,1)+'_block}']
    end

    if fileinfo(lisf(i,1)+'/'+lisf(i,1)+'_used_func.tex')<>[] then //Used function
      tt9=[tex_title(9)
           '\input{'+lisf(i,1)+'_used_func}']
    end

    if fileinfo(lisf(i,1)+'/'+lisf(i,1)+'_see_also.tex')<>[] then //see also
      tt10=[tex_title(10)
            '\input{'+lisf(i,1)+'_see_also}']
    end

    if fileinfo(lisf(i,1)+'/'+lisf(i,1)+'_bib.tex')<>[] then //bibliography
      tt12=['\input{'+lisf(i,1)+'_bib.tex}']
    end

    if flag=='guide' then
          tt1=['\section{'+latexsubst(lisf(i,2))+'}\label{'+lisf(i,1)+'}'];

    elseif flag=='html' then

    if lang=='fr' then //Header of tex file
      tt1=['\documentclass[11pt,frenchb]{article}']
    else
      tt1=['\documentclass[11pt]{article}']
    end
    tt1=[tt1;
         '\usepackage{makeidx,graphics,fullpage}'
         '\usepackage{verbatim,times,amsmath,amssymb,epsfig,color}'
         '\usepackage{html}'
         '\begin{document}']
    if lang=='fr' then
      tt1=[tt1;'\begin{center}Script de simulation Scilab\\']
    else
      tt1=[tt1;'\begin{center}'+lisf(i,3)+'\\']
    end
    tt1=[tt1
         '\htmladdnormallink{eng}{../eng/'+lisf(i,1)+'.htm}\hspace{2mm}-'+...
         '\hspace{2mm}\htmladdnormallink{fr}{../fr/'+lisf(i,1)+'.htm}}'
         '\end{center}'];
    tt1=[tt1
         '\section{'+latexsubst(lisf(i,2))+'}\label{'+lisf(i,1)+'}'
         '\tableofcontents'
        ]

    if fileinfo(lisf(i,1)+'/'+lisf(i,1)+'_authors.tex')<>[] then //authors
      tt11=[tex_title(11)
            '\input{'+lisf(i,1)+'_authors}']
    end

    tt13=['\htmlinfo*';'\end{document}']
    end

    //Generate the main tex file of block
    txt=[]
    for j=1:13 txt=[txt;evstr('tt'+string(j))], end
    mputl(txt,lisf(i,1)+'/'+lisf(i,1)+'.tex')
 end

endfunction
